==> openx-2.5.69-beta.tar.bz2: openx-2.5.69-beta/lib/max/language/zh_CN/invocation.lang.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.5                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2008 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: invocation.lang.php 21310 2008-06-12 11:12:19Z david.keen@openx.org $
*/

// Invocation Types
$GLOBALS['strInvocationRemote']			= "Զ̵";
$GLOBALS['strInvocationJS']			= "Զ̵Javascript";
$GLOBALS['strInvocationIframes']		= "Զ̵Frames";
$GLOBALS['strInvocationXmlRpc']			= "Զ̵XML-RPC";
$GLOBALS['strInvocationCombined']		= "Զ̵";
$GLOBALS['strInvocationPopUp']			= "";
$GLOBALS['strInvocationAdLayer']		= "϶ƯDHTML";
$GLOBALS['strInvocationLocal']			= "ģʽ";


// Other
$GLOBALS['strCopyToClipboard']			= "拷贝到粘贴板";


// Measures
$GLOBALS['strAbbrPixels']			= "px";
$GLOBALS['strAbbrSeconds']			= "秒";


// Common Invocation Parameters
$GLOBALS['strInvocationWhat']			= "选择广告";
$GLOBALS['strInvocationClientID']		= "ͻĿ";
$GLOBALS['strInvocationTarget']			= "目标Frame";
$GLOBALS['strInvocationSource']			= "来源";
$GLOBALS['strInvocationWithText']		= "广告现显示的文字";
$GLOBALS['strInvocationDontShowAgain']		= "同一页不重复显示相同广告";
$GLOBALS['strInvocationDontShowAgainCampaign']	= "同一页不显示相同项目";
$GLOBALS['strInvocationTemplate'] 		= "保存广告变量作为将来使用的模板";


// Iframe
$GLOBALS['strIFrameRefreshAfter']		= "于此之后刷新";
$GLOBALS['strIframeResizeToBanner']		= "按照广告尺寸重新设置iframe大小";
$GLOBALS['strIframeMakeTransparent']		= "iframe透明";
$GLOBALS['strIframeIncludeNetscape4']		= "兼容Netscape4或更高版本";


// PopUp
$GLOBALS['strPopUpStyle']			= "";
$GLOBALS['strPopUpStylePopUp']			= "";
$GLOBALS['strPopUpStylePopUnder']		= "";
$GLOBALS['strPopUpCreateInstance']		= "ʽ";
$GLOBALS['strPopUpImmediately']			= "";
$GLOBALS['strPopUpOnClose']			= "ҳرʱ";
$GLOBALS['strPopUpAfterSec']			= "ʱ";
$GLOBALS['strAutoCloseAfter']			= "Զرʱ";
$GLOBALS['strPopUpTop']				= "ʼλ()";
$GLOBALS['strPopUpLeft']			= "ʼλ()";
$GLOBALS['strWindowOptions']			= "ѡ";
$GLOBALS['strShowToolbars']			= "";
$GLOBALS['strShowLocation']			= "ַ";
$GLOBALS['strShowMenubar']			= "˵";
$GLOBALS['strShowStatus']			= "״̬";
$GLOBALS['strWindowResizable']			= "ɵС";
$GLOBALS['strShowScrollbars']			= "";


// XML-RPC
$GLOBALS['strXmlRpcLanguage']			= "";


// AdLayer
$GLOBALS['strAdLayerStyle']			= "风格";

$GLOBALS['strAlignment']			= "";
$GLOBALS['strHAlignment']			= "";
$GLOBALS['strLeft']				= "";
$GLOBALS['strCenter']				= "";
$GLOBALS['strRight']				= "";

$GLOBALS['strVAlignment']			= "";
$GLOBALS['strTop']				= "";
$GLOBALS['strMiddle']				= "в";
$GLOBALS['strBottom']				= "ײ";

$GLOBALS['strAutoCollapseAfter']		= "Զ۵ʱ";
$GLOBALS['strCloseText']			= "ر";
$GLOBALS['strClose']				= "[ر]";
$GLOBALS['strBannerPadding']			= "油";

$GLOBALS['strHShift']				= "ƶ";
$GLOBALS['strVShift']				= "ƶ";

$GLOBALS['strShowCloseButton']			= "ʾرհť";
$GLOBALS['strBackgroundColor']			= "ɫ";
$GLOBALS['strBorderColor']			= "߿ɫ";

$GLOBALS['strDirection']			= "";
$GLOBALS['strLeftToRight']			= "";
$GLOBALS['strRightToLeft']			= "ҵ";
$GLOBALS['strLooping']				= "ѭ";
$GLOBALS['strAlwaysActive']			= "";
$GLOBALS['strSpeed']				= "ٶ";
$GLOBALS['strPause']				= "ͣ";
$GLOBALS['strLimited']				= "";
$GLOBALS['strLeftMargin']			= "߽";
$GLOBALS['strRightMargin']			= "ұ߽";
$GLOBALS['strTransparentBackground']		= "͸";

$GLOBALS['strSmoothMovement']			= "ƽƶ";
$GLOBALS['strHideNotMoving']			= "겻ƶʱع";
$GLOBALS['strHideDelay']			= "عǰʱӳ";
$GLOBALS['strHideTransparancy']			= "ʹصĹ͸";


$GLOBALS['strAdLayerStyleName']['geocities'] = "个人主页";
$GLOBALS['strAdLayerStyleName']['simple'] = "简单式";
$GLOBALS['strAdLayerStyleName']['cursor'] = "光标式";
$GLOBALS['strAdLayerStyleName']['floater'] = "浮动式";




// Note: new translatiosn not found in original lang files but found in CSV
$GLOBALS['strCopy'] = "拷贝";
$GLOBALS['strInvocationCampaignID'] = "项目";
$GLOBALS['strInvocationBannerID'] = "广告ID";
$GLOBALS['strInvocationComments'] = "包括注释";
$GLOBALS['str3rdPartyTrack'] = "支持第三方广告跟踪服务器";
$GLOBALS['strCacheBuster'] = "插入Icache-Busitng代码";
$GLOBALS['strImgWithAppendWarning'] = "跟踪器带有附加代码，这些附加代码必须在JavaScript标签中才可运行。";
?>

==> openx-2.7.27-beta.tar.bz2: openx-2.7.27-beta/lib/max/language/zh_CN/invocation.lang.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.7                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2008 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: invocation.lang.php 29689 2008-12-03 16:30:29Z andrew.hill $
*/

// Invocation Types
$GLOBALS['strInvocationRemote']			= "Զ̵";
$GLOBALS['strInvocationJS']			= "Զ̵Javascript";
$GLOBALS['strInvocationIframes']		= "Զ̵Frames";
$GLOBALS['strInvocationXmlRpc']			= "Զ̵XML-RPC";
$GLOBALS['strInvocationCombined']		= "Զ̵";
$GLOBALS['strInvocationPopUp']			= "";
$GLOBALS['strInvocationAdLayer']		= "϶ƯDHTML";
$GLOBALS['strInvocationLocal']			= "ģʽ";


// Other
$GLOBALS['strCopyToClipboard']			= "拷贝到粘贴板";


// Measures
$GLOBALS['strAbbrPixels']			= "px";
$GLOBALS['strAbbrSeconds']			= "秒";


// Common Invocation Parameters
$GLOBALS['strInvocationWhat']			= "选择广告";
$GLOBALS['strInvocationClientID']		= "ͻĿ";
$GLOBALS['strInvocationTarget']			= "目标Frame";
$GLOBALS['strInvocationSource']			= "来源";
$GLOBALS['strInvocationWithText']		= "广告现显示的文字";
$GLOBALS['strInvocationDontShowAgain']		= "同一页不重复显示相同广告";
$GLOBALS['strInvocationDontShowAgainCampaign']	= "同一页不显示相同项目";
$GLOBALS['strInvocationTemplate'] 		= "保存广告变量作为将来使用的模板";


// Iframe
$GLOBALS['strIFrameRefreshAfter']		= "于此之后刷新";
$GLOBALS['strIframeResizeToBanner']		= "按照广告尺寸重新设置iframe大小";
$GLOBALS['strIframeMakeTransparent']		= "iframe透明";
$GLOBALS['strIframeIncludeNetscape4']		= "兼容Netscape4或更高版本";


// PopUp
$GLOBALS['strPopUpStyle']			= "";
$GLOBALS['strPopUpStylePopUp']			= "";
$GLOBALS['strPopUpStylePopUnder']		= "";
$GLOBALS['strPopUpCreateInstance']		= "ʽ";
$GLOBALS['strPopUpImmediately']			= "";
$GLOBALS['strPopUpOnClose']			= "ҳرʱ";
$GLOBALS['strPopUpAfterSec']			= "ʱ";
$GLOBALS['strAutoCloseAfter']			= "Զرʱ";
$GLOBALS['strPopUpTop']				= "ʼλ()";
$GLOBALS['strPopUpLeft']			= "ʼλ()";
$GLOBALS['strWindowOptions']			= "ѡ";
$GLOBALS['strShowToolbars']			= "";
$GLOBALS['strShowLocation']			= "ַ";
$GLOBALS['strShowMenubar']			= "˵";
$GLOBALS['strShowStatus']			= "״̬";
$GLOBALS['strWindowResizable']			= "ɵС";
$GLOBALS['strShowScrollbars']			= "";


// XML-RPC
$GLOBALS['strXmlRpcLanguage']			= "";


// AdLayer
$GLOBALS['strAdLayerStyle']			= "风格";

$GLOBALS['strAlignment']			= "";
$GLOBALS['strHAlignment']			= "";
$GLOBALS['strLeft']				= "";
$GLOBALS['strCenter']				= "";
$GLOBALS['strRight']				= "";

$GLOBALS['strVAlignment']			= "";
$GLOBALS['strTop']				= "";
$GLOBALS['strMiddle']				= "в";
$GLOBALS['strBottom']				= "ײ";

$GLOBALS['strAutoCollapseAfter']		= "Զ۵ʱ";
$GLOBALS['strCloseText']			= "ر";
$GLOBALS['strClose']				= "[ر]";
$GLOBALS['strBannerPadding']			= "油";

$GLOBALS['strHShift']				= "ƶ";
$GLOBALS['strVShift']				= "ƶ";

$GLOBALS['strShowCloseButton']			= "ʾرհť";
$GLOBALS['strBackgroundColor']			= "ɫ";
$GLOBALS['strBorderColor']			= "߿ɫ";

$GLOBALS['strDirection']			= "";
$GLOBALS['strLeftToRight']			= "";
$GLOBALS['strRightToLeft']			= "ҵ";
$GLOBALS['strLooping']				= "ѭ";
$GLOBALS['strAlwaysActive']			= "";
$GLOBALS['strSpeed']				= "ٶ";
$GLOBALS['strPause']				= "暂停";
$GLOBALS['strLimited']				= "";
$GLOBALS['strLeftMargin']			= "߽";
$GLOBALS['strRightMargin']			= "ұ߽";
$GLOBALS['strTransparentBackground']		= "͸";

$GLOBALS['strSmoothMovement']			= "ƽƶ";
$GLOBALS['strHideNotMoving']			= "겻ƶʱع";
$GLOBALS['strHideDelay']			= "عǰʱӳ";
$GLOBALS['strHideTransparancy']			= "ʹصĹ͸";


$GLOBALS['strAdLayerStyleName']['geocities'] = "个人主页";
$GLOBALS['strAdLayerStyleName']['simple'] = "简单式";
$GLOBALS['strAdLayerStyleName']['cursor'] = "光标式";
$GLOBALS['strAdLayerStyleName']['floater'] = "浮动式";




// Note: new translatiosn not found in original lang files but found in CSV
$GLOBALS['strCopy'] = "拷贝";
$GLOBALS['strInvocationCampaignID'] = "项目";
$GLOBALS['strInvocationBannerID'] = "广告ID";
$GLOBALS['strInvocationComments'] = "包括注释";
$GLOBALS['str3rdPartyTrack'] = "支持第三方广告跟踪服务器";
$GLOBALS['strCacheBuster'] = "插入Icache-Busitng代码";
$GLOBALS['strImgWithAppendWarning'] = "跟踪器带有附加代码，这些附加代码必须在JavaScript标签中才可运行。";


// Note: New translations not found in original lang files but found in CSV
$GLOBALS['strIframeGoogleClickTracking'] = "插入一段代码，统计Google AdSense点击";
$GLOBALS['strWarningLocalInvocation'] = "<span class='tab-s'><strong>警告:</strong>本地模式中，系统将只会返回这台服务器的广告请求</span><br />请检查代码内的 MAX_PATH <br />，你将会在MAX_PATH/var 内有一个以你域名为文件名的配置文件";
$GLOBALS['strChooseTypeOfInvocation'] = "请选择生成的公告形式";
$GLOBALS['strChooseTypeOfBannerInvocation'] = "请选择生成的公告形式";
?>
